keys — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# keys

The keys that may be used in the game.

`keys.` `ADD_LINES` = [52]

  Add a random number to Eric’s lines total.

`keys.` `CATCH` = [99]

  Try to catch a mouse or frog.

`keys.` `CLOSE_DOORS` = [281]

  Close all doors and windows.

`keys.` `DOWN` = [274, 97]

  Down.

`keys.` `DROP_STINKBOMB` = [100]

  Drop a stinkbomb.

`keys.` `DUMP_WATER_PISTOL` = [116]

  Throw away the water pistol.

`keys.` `ENTER` = [13]

  Stop writing on a blackboard.

`keys.` `FAST` = [48]

  Try to double the speed of the game (key must be held down).

`keys.` `FIRE_CATAPULT` = [102]

  Fire the catapult.

`keys.` `FIRE_WATER_PISTOL` = [103]

  Fire the water pistol.

`keys.` `FLASH_MOST` = [49]

  Make all but one shield flash.

`keys.` `FULL_SCREEN` = [292]

  Toggle full-screen mode.

`keys.` `GIVE_ALL` = [55]

  Fill Eric’s inventory.

`keys.` `HIT` = [104]

  Throw a punch.

`keys.` `JUMP` = [106]

  Jump.

`keys.` `KISS` = [107]

  Kiss.

`keys.` `LEFT` = [276, 111]

  Left.

`keys.` `LOAD` = [287]

  Load the most recently saved game.

`keys.` `MENU` = [293]

  Display the menu.

`keys.` `MENU_EXEC` = [13, 32]

  Execute the selected menu item.

`keys.` `MENU_EXIT` = [293, 27]

  Exit the menu.

`keys.` `MENU_NEXT` = [274, 97]

  Select the next item in the menu.

`keys.` `MENU_PREV` = [273, 113]

  Select the previous item in the menu.

`keys.` `MOUNT_BIKE` = [109]

  Mount the bike.

`keys.` `NEXT_LESSON` = [9]

  Proceed to the next lesson.

`keys.` `NO_LINES` = [51]

  Prevent teachers from giving lines.

`keys.` `OPEN_DESK` = [111]

  Open a desk.

`keys.` `OPEN_DOORS` = [280]

  Open all doors and windows.

`keys.` `PAUSE` = [279]

  Pause.

`keys.` `QUIT` = [27]

  Quit.

`keys.` `RELEASE_MICE` = [114]

  Release some mice.

`keys.` `REVEAL` = [54]

  Reveal all combinations, the locations of the stinkbombs and the water pistol, and the answers to any special questions.

`keys.` `RIGHT` = [275, 112]

  Right.

`keys.` `SAVE` = [283]

  Save the game.

`keys.` `SCREENSHOT` = [277]

  Take a screenshot.

`keys.` `SIT_STAND` = [115]

  Sit/stand.

`keys.` `SLOW` = [57]

  Slow the game down to half speed (key must be held down).

`keys.` `SWITCH_PISTOL` = [56]

  Toggle between a water-filled and sherry-filled water pistol.

`keys.` `UNDERSTOOD` = [117]

  Acknowledge understanding of a message.

`keys.` `UNFLASH_MOST` = [50]

  Make all but one shield unflash.

`keys.` `UP` = [273, 113]

  Up.

`keys.` `WRITE` = [119]

  Start writing on a blackboard.

`keys.` `ZERO_LINES` = [53]

  Set Eric’s lines total to zero.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »